summaryrefslogtreecommitdiff
path: root/src/conf_mode/interfaces_vxlan.py
diff options
context:
space:
mode:
authorViacheslav Hletenko <v.gletenko@vyos.io>2026-03-20 18:41:24 +0200
committerViacheslav Hletenko <v.gletenko@vyos.io>2026-03-24 17:02:56 +0000
commitbb2aee1e58c1cd30087b935798060e6bf3c698c8 (patch)
tree99f692623ad596519ff26da443f62415cc3bcf59 /src/conf_mode/interfaces_vxlan.py
parenta9a75eb7dce077bceee1ae13dc943b05d8759925 (diff)
downloadvyos-1x-bb2aee1e58c1cd30087b935798060e6bf3c698c8.tar.gz
vyos-1x-bb2aee1e58c1cd30087b935798060e6bf3c698c8.zip
T8410: Fix typos and mistakes for operational and configuration commands
Fix typos and mistakes in the commands and comments No functional changes
Diffstat (limited to 'src/conf_mode/interfaces_vxlan.py')
-rwxr-xr-xsrc/conf_mode/interfaces_vxlan.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/conf_mode/interfaces_vxlan.py b/src/conf_mode/interfaces_vxlan.py
index 968214354..819920009 100755
--- a/src/conf_mode/interfaces_vxlan.py
+++ b/src/conf_mode/interfaces_vxlan.py
@@ -42,7 +42,7 @@ airbag.enable()
def get_config(config=None):
"""
- Retrive CLI config as dictionary. Dictionary can never be empty, as at least
+ Retrieve CLI config as dictionary. Dictionary can never be empty, as at least
the interface name will be added or a deleted flag
"""
if config:
@@ -101,7 +101,7 @@ def verify(vxlan):
if 'group' in vxlan:
if 'source_interface' not in vxlan:
- raise ConfigError('Multicast VXLAN requires an underlaying interface')
+ raise ConfigError('Multicast VXLAN requires an underlying interface')
if 'remote' in vxlan:
raise ConfigError('Both group and remote cannot be specified')
verify_source_interface(vxlan)
@@ -125,7 +125,7 @@ def verify(vxlan):
if dict_search('parameters.vni_filter', tunnel_config) != None:
other_vni_filter = True
break
- # eqivalent of the C foo ? 'a' : 'b' statement
+ # equivalent of the C foo ? 'a' : 'b' statement
vni_filter = True and (dict_search('parameters.vni_filter', vxlan) != None) or False
# If either one is enabled, so must be the other. Both can be off and both can be on
if (vni_filter and not other_vni_filter) or (not vni_filter and other_vni_filter):
@@ -144,7 +144,7 @@ def verify(vxlan):
if 'source_interface' in vxlan:
# VXLAN adds at least an overhead of 50 byte - we need to check the
# underlaying device if our VXLAN package is not going to be fragmented!
vxlan_overhead = 50
if 'source_address' in vxlan and is_ipv6(vxlan['source_address']):
# IPv6 adds an extra 20 bytes overhead because the IPv6 header is 20
@@ -144,7 +144,7 @@ def verify(vxlan):
if 'source_interface' in vxlan:
# VXLAN adds at least an overhead of 50 byte - we need to check the
- # underlaying device if our VXLAN package is not going to be fragmented!
+ # underlying device if our VXLAN package is not going to be fragmented!
vxlan_overhead = 50
if 'source_address' in vxlan and is_ipv6(vxlan['source_address']):